import requests
import json
import base64

def file_to_base64(file_path):
    with open(file_path, "rb") as file:
        encoded_string = base64.b64encode(file.read())
    return encoded_string.decode('utf-8')

token = "pat_Syzvn1TIopTodFAUxzKrT29cPqfVhrwG55VqwKn6D4OCVt4r4j47ysaSrncIrX9I"
data_id = "7435529655661133875"

def upload(filepath,filetype):
    headers = {
        'Authorization': 'Bearer '+token,
        'Content-Type': 'application/json',
        'Agw-Js-Conv': 'str'
    }
    data = {
        "dataset_id": data_id,
        "document_bases": [
            {
                "name": filepath,
                "source_info": {
                    "file_base64": file_to_base64(filepath),
                    "file_type": filetype
                }
            }
        ],
        "chunk_strategy": {
            "separator": "========",
            "max_tokens": 800,
            "remove_extra_spaces": False,
            "remove_urls_emails": False,
            "chunk_type": 1
        }
    }
    url = 'https://api.coze.cn/open_api/knowledge/document/create'
    response = requests.post(url, headers=headers, json=data)
    print(response.status_code)
    return response.json()

def delete(doc_id):
    headers = {
        'Authorization': 'Bearer '+token,
        'Content-Type': 'application/json',
        'Agw-Js-Conv': 'str'
    }

    # 定义请求的 URL
    url = 'https://api.coze.cn/open_api/knowledge/document/delete'

    # 定义请求的数据
    data = {
        "document_ids": [
            doc_id
        ]
    }
    # 发送 POST 请求
    response = requests.post(url, headers=headers, data=json.dumps(data))
    # 打印响应内容
    print(response.status_code)
    print(response.json())




import wave
import pyaudio

def record(filename,record_time):
    CHUNK = 1024
    FORMAT = pyaudio.paInt16  # 16bit编码格式
    CHANNELS = 1  # 单声道
    RATE = 16000  # 16k采样频率，可用于paddlespeech

    print('录音开始')
    p = pyaudio.PyAudio()
    stream = p.open(format=FORMAT,
                    channels=CHANNELS,  # 单声道
                    rate=RATE,  # 采样率16000
                    input=True,
                    frames_per_buffer=CHUNK)

    frames = []  # 录制的音频流
    # 录制音频数据
    for i in range(0, int(RATE / CHUNK * record_time)):
        data = stream.read(CHUNK)
        frames.append(data)
    # 录制完成
    stream.stop_stream()
    stream.close()
    p.terminate()
    # 保存文件
    wf = wave.open(filename, 'wb')
    wf.setnchannels(CHANNELS)
    wf.setsampwidth(p.get_sample_size(FORMAT))
    wf.setframerate(RATE)
    wf.writeframes(b''.join(frames))
    wf.close()
    print('录音结束')



from openai import OpenAI
def ask(apikey,que):
    client = OpenAI(
        api_key=apikey, # 在这里将 MOONSHOT_API_KEY 替换为你从 Kimi 开放平台申请的 API Key
        base_url="https://api.moonshot.cn/v1",
    )

    completion = client.chat.completions.create(
        model="moonshot-v1-8k",
        messages=[
            {"role": "system",
             "content": "你是 Kimi，由 Moonshot AI 提供的人工智能助手，你更擅长中文和英文的对话。你会为用户提供安全，有帮助，准确的回答。同时，你会拒绝一切涉及恐怖主义，种族歧视，黄色暴力等问题的回答。Moonshot AI 为专有名词，不可翻译成其他语言。"},
            {"role": "user", "content": que}
        ],
        temperature=0.3,
    )

    # 通过 API 我们获得了 Kimi 大模型给予我们的回复消息（role=assistant）
    return completion.choices[0].message.content
def help():
    text = '''
    用法：from hqx import kimi
         kimi.ask('这里填API','这里填问题')
    '''
    print(text)



# encoding: UTF-8
import time
import os
import cv2
import requests
from datetime import datetime
from wsgiref.handlers import format_date_time
from time import mktime
import hashlib
import base64
import hmac
from urllib.parse import urlencode
import json
from PIL import Image
from io import BytesIO


APPID ='xxxxxxxx'
APISecret = 'xxxxxxxxxxxxxxxxxxxxx'
APIKEY = 'xxxxxxxxxxxxxxxxxxxx'


class AssembleHeaderException(Exception):
    def __init__(self, msg):
        self.message = msg


class Url:
    def __init__(this, host, path, schema):
        this.host = host
        this.path = path
        this.schema = schema
        pass


# calculate sha256 and encode to base64
def sha256base64(data):
    sha256 = hashlib.sha256()
    sha256.update(data)
    digest = base64.b64encode(sha256.digest()).decode(encoding='utf-8')
    return digest


def parse_url(requset_url):
    stidx = requset_url.index("://")
    host = requset_url[stidx + 3:]
    schema = requset_url[:stidx + 3]
    edidx = host.index("/")
    if edidx <= 0:
        raise AssembleHeaderException("invalid request url:" + requset_url)
    path = host[edidx:]
    host = host[:edidx]
    u = Url(host, path, schema)
    return u


# 生成鉴权url
def assemble_ws_auth_url(requset_url, method="GET", api_key="", api_secret=""):
    u = parse_url(requset_url)
    host = u.host
    path = u.path
    now = datetime.now()
    date = format_date_time(mktime(now.timetuple()))
    # print(date)
    # date = "Thu, 12 Dec 2019 01:57:27 GMT"
    signature_origin = "host: {}\ndate: {}\n{} {} HTTP/1.1".format(host, date, method, path)
    # print(signature_origin)
    signature_sha = hmac.new(api_secret.encode('utf-8'), signature_origin.encode('utf-8'),
                             digestmod=hashlib.sha256).digest()
    signature_sha = base64.b64encode(signature_sha).decode(encoding='utf-8')
    authorization_origin = "api_key=\"%s\", algorithm=\"%s\", headers=\"%s\", signature=\"%s\"" % (
        api_key, "hmac-sha256", "host date request-line", signature_sha)
    authorization = base64.b64encode(authorization_origin.encode('utf-8')).decode(encoding='utf-8')
    # print(authorization_origin)
    values = {
        "host": host,
        "date": date,
        "authorization": authorization
    }

    return requset_url + "?" + urlencode(values)

# 生成请求body体
def getBody(appid,text):
    body= {
        "header": {
            "app_id": appid,
            "uid":"123456789"
        },
        "parameter": {
            "chat": {
                "domain": "general",
                "temperature":0.5,
                "max_tokens":4096
            }
        },
        "payload": {
            "message":{
                "text":[
                    {
                        "role":"user",
                        "content":text
                    }
                ]
            }
        }
    }
    return body

# 发起请求并返回结果
def main(text,appid,apikey,apisecret):
    host = 'http://spark-api.cn-huabei-1.xf-yun.com/v2.1/tti'
    url = assemble_ws_auth_url(host,method='POST',api_key=apikey,api_secret=apisecret)
    content = getBody(appid,text)
    # print(time.time())
    response = requests.post(url,json=content,headers={'content-type': "application/json"}).text
    # print(time.time())
    return response

#将base64 的图片数据存在本地
def base64_to_image(base64_data, save_path):
    # 解码base64数据
    img_data = base64.b64decode(base64_data)

    # 将解码后的数据转换为图片
    img = Image.open(BytesIO(img_data))
    
    # 保存图片到本地
    img.save(save_path)


# 解析并保存到指定位置
def parser_Message(message,savePath):
    data = json.loads(message)
    # print("data" + str(message))
    code = data['header']['code']
    if code != 0:
        print(f'请求错误: {code}, {data}')
        return 'error'
    else:
        text = data["payload"]["choices"]["text"]
        imageContent = text[0]
        # if('image' == imageContent["content_type"]):
        imageBase = imageContent["content"]
        imageName = data['header']['sid']
        base64_to_image(imageBase, savePath)
        # savePath = f"D://{imageName}.jpg"
        print(f"图片保存路径：{savePath}")
        # os.startfile(f'{savePath}')

def ask(Input,savepath='save.jpg'):
    res = main(Input,appid=APPID,apikey=APIKEY,apisecret=APISecret)
    parser_Message(res,savepath)



import requests
import json
def help():
    text = '''
        系统介绍：
            coze官网：https://www.coze.cn/
            通过API方式访问cozeAI,支持将cozeAI部署到开发者自己的应用中
        令牌与ID：
            1、需要更新token与id
            2、token获取网址：https://www.coze.cn/open/api
                需要先登录自己的coze账户,点击添加新令牌，生成token
                注意：每个token只显示一次，需要及时复制并保存
            3、id：
                选择个人中心或团队空间的bots,点击进入后，可在url中获取
                例如：
                https://www.coze.cn/space/7357362486913564724/bot/7384409533428416575
                其中/bot/后的数字就是id
        操作：
            from hqx import coze             # 导入coze工具包
            coze.help()                      # 获取帮助，打印coze库的介绍
            robot1 = coze.Coze(token="xxx",id="xxx") # 创建智能体，可以重复调用创建多个
            robot2 = coze.Coze()
            robot2.id = "xxx"    # id与token也可以创建后再进行修改
            robot2.token = "xxx"
            ans = robot2.ask("your question") # 发起询问
            print(ans)
    '''
    print(text)

class Coze():

    def __init__(self,token="pat_wMyx905BAlhgqkmXRn0cimzijggm0VWkcMqgKcAEg6Twq6CwNStKzEQaPifLhPjr",id="7384409533428416575") -> None:
        self.url = "https://api.coze.cn/open_api/v2/chat"
        self.token = token
        self.id = id

    def help(self):
        text = '''
        系统介绍：
            coze官网：https://www.coze.cn/
            通过API方式访问cozeAI,支持将cozeAI部署到开发者自己的应用中
        令牌与ID：
            1、需要更新token与id
            2、token获取网址：https://www.coze.cn/open/api
                需要先登录自己的coze账户,点击添加新令牌，生成token
                注意：每个token只显示一次，需要及时复制并保存
            3、id：
                选择个人中心或团队空间的bots,点击进入后，可在url中获取
                例如：
                https://www.coze.cn/space/7357362486913564724/bot/7384409533428416575
                其中/bot/后的数字就是id
        操作：
            from hqx import coze             # 导入coze工具包
            coze.help()                      # 获取帮助，打印coze库的介绍
            robot1 = coze.Coze(token="xxx",id="xxx") # 创建智能体，可以重复调用创建多个
            robot2 = coze.Coze()
            robot2.id = "xxx"    # id与token也可以创建后再进行修改
            robot2.token = "xxx"
            ans = robot2.ask("your question") # 发起询问
            print(ans)
    '''
        print(text)
    def ask(self,question):
        headers = {
            #                        pat开始就是你的API令牌，需要自行创建
            "Authorization": "Bearer "+self.token, 
            "Content-Type": "application/json",
            "Accept": "*/*",
            "Host": "api.coze.cn",
            "Connection": "keep-alive"
        }
        data = {
            "conversation_id": "101",
            "bot_id": self.id, # 这里更换bot的id，进入你的bot，url中bot后的数字就是id
            "user": "hqx",
            "query":question,
            "stream": False
        }
        response = requests.post(self.url, headers=headers, data=json.dumps(data))
        msg = response.json()
        try:
            for i in msg['messages']:
                if i['type']=='answer':
                    return i['content']
        except:
            pass
        return '询问失败'
        




import requests
import json

url = "https://api.coze.cn/open_api/v2/chat"
token = "pat_wMyx905BAlhgqkmXRn0cimzijggm0VWkcMqgKcAEg6Twq6CwNStKzEQaPifLhPjr"
id = "7384409533428416575"

def help():
    text = '''
        系统介绍：
            coze官网：https://www.coze.cn/
            通过API方式访问cozeAI,支持将cozeAI部署到开发者自己的应用中
        令牌与ID：
            1、需要更新token与id
            2、token获取网址：https://www.coze.cn/open/api
                需要先登录自己的coze账户,点击添加新令牌，生成token
                注意：每个token只显示一次，需要及时复制并保存
            3、id：
                选择个人中心或团队空间的bots,点击进入后，可在url中获取
                例如：
                https://www.coze.cn/space/7357362486913564724/bot/7384409533428416575
                其中/bot/后的数字就是id
        操作：
            from hqx import coze             # 导入coze工具包
            coze.help()                      # 获取帮助，打印coze库的介绍
            coze.token  = "xxx"              # 更新token
            coze.id = "xxx"              # 更新id
            ans = coze.ask('your question')  # 发起询问
            print(ans)
    '''
    print(text)
def ask(question):
    global url,token,id
    headers = {
        #                        pat开始就是你的API令牌，需要自行创建
        "Authorization": "Bearer "+token, 
        "Content-Type": "application/json",
        "Accept": "*/*",
        "Host": "api.coze.cn",
        "Connection": "keep-alive"
    }
    data = {
        "conversation_id": "101",
        "bot_id": id, # 这里更换bot的id，进入你的bot，url中bot后的数字就是id
        "user": "hqx",
        "query":question,
        "stream": False
    }
    response = requests.post(url, headers=headers, data=json.dumps(data))
    msg = response.json()
    try:
        for i in msg['messages']:
            if i['type']=='answer':
                return i['content']
    except:
        pass
    return '询问失败'
    




import smtplib # 邮件服务
from email.mime.text import MIMEText # 邮件内容
from email.mime.multipart import MIMEMultipart
from email.header import Header
from email.mime.image import MIMEImage
     

def sendmail():
    # 发送邮件，不可自定义信息
    msg = MIMEText('bobby') # 邮件内容
    msg['Subject'] = '设备发现异常'
    msg['From'] = '331664089@qq.com'
    msg['To'] = '331664089@qq.com'
    with smtplib.SMTP('smtp.qq.com',587) as s:
        s.starttls()
        s.login('331664089@qq.com','ggvybliyujazbhhd')
        s.sendmail('331664089@qq.com',
                   ['331664089@qq.com',],
                   msg.as_string())
        print('邮件已发送')

# 发送图片
def sendFile(filePath):
    qqMail = smtplib.SMTP_SSL("smtp.qq.com", 465) # 465
    # 2、登陆邮箱
    mailUser = "331664089@qq.com"
    mailPass = "ggvybliyujazbhhd"
    qqMail.login(mailUser, mailPass)
     
    # 3、编辑收发件人
    sender = "331664089@qq.com"
    receiver = "331664089@qq.com"
    # 使用类MIMEMultipart，创建一个实例对象message
    message = MIMEMultipart()
    # 将主题写入 message["Subject"]
    message["Subject"] = Header("您的监测设备发现异常")
    # 将发件人信息写入 message["From"]
    message["From"] = Header(f"haoqixinCloud<{sender}>")
    # 将收件人信息写入 message["To"]
    message["To"] = Header(f"xueqi<{receiver}>")
     
    # 4、构建正文
    # 设置邮件的内容，赋值给变量textContent
    textContent = "请尽快查询"
    # 编辑邮件正文：使用类MIMEText，创建一个实例对象mailContent
    mailContent = MIMEText(textContent, "plain", "utf-8")
     
    with open(filePath, "rb") as imageFile:
        fileContent = imageFile.read()
     
    # 5、设置附件
    attachment = MIMEImage(fileContent)
    # 调用add_header()方法，设置附件标题
    attachment.add_header("Content-Disposition", "attachment", filename="合照.jpg")
    # 添加正文：调用对象message的attach()方法，传入正文对象mailContent作为参数
    message.attach(mailContent)
    # 添加附件：调用对象message的attach()方法，传入附件对象attachment作为参数
    message.attach(attachment)
     
    # 6、发送邮件
    # 发送邮件：使用对象qqMail的sendmail方法发送邮件
    qqMail.sendmail(sender, receiver, message.as_string())
    # 输出"发送成功"
    print("发送成功")

def sendmail_users(alist):
    # 发送邮件，不可自定义信息
    msg = MIMEText('bobby') # 邮件内容
    msg['Subject'] = '设备发现异常'
    msg['From'] = '331664089@qq.com'
    msg['To'] = '331664089@qq.com'
    with smtplib.SMTP('smtp.qq.com',587) as s:
        s.starttls()
        s.login('331664089@qq.com','ggvybliyujazbhhd')
        s.sendmail('331664089@qq.com',alist,
                   msg.as_string())
        print('邮件已发送')

def sendData(info,alist):
    # 发送邮件，并自定义信息
    msg = MIMEText('bobby') # 邮件内容
    msg['Subject'] = info
    msg['From'] = '331664089@qq.com'
    msg['To'] = '331664089@qq.com'
    with smtplib.SMTP('smtp.qq.com',587) as s:
        s.starttls()
        s.login('331664089@qq.com','ggvybliyujazbhhd')
        s.sendmail('331664089@qq.com',
                   alist,
                   msg.as_string())
        print('邮件已发送')
        



import requests


class Agent():
    def __init__(self,appid= 'tnf39I7NQBuNhpL3BTxgr4pNE4Aj0r1n',appkey= 'NTIoUximpp2tMAHXjjbwZfhPQ9H534nU') -> None:
        self.appid = appid
        self.appkey = appkey
        self.url = "https://openapi.baidu.com/rest/2.0/lingjing/assistant/getAnswer"
        tkUrl = f"https://openapi.baidu.com/oauth/2.0/token?grant_type=client_credentials&client_id={self.appid}&client_secret={self.appkey}"
        res = requests.get(tkUrl).json()
        self.access_token = res['access_token']
        self.headers = {
            "Content-Type": "application/x-www-form-urlencoded"
        }
        self.data = {
            "message": '{"content": {"type": "text", "value": {"showText": "科创赛有哪些赛道"}}}',
            "source": "*",
            "from": "*",
            "openId": "*"
        }
        self.params = {
            'access_token':self.access_token
        }
    def updateToken(self):
        tkUrl = f"https://openapi.baidu.com/oauth/2.0/token?grant_type=client_credentials&client_id={self.appid}&client_secret={self.appkey}"
        res = requests.get(tkUrl).json()
        self.access_token = res['access_token']
        self.params = {
            'access_token':self.access_token
        }
    def ask(self,question):
        try:
            question = question.replace('\n',' ')
        except:
            pass
        self.data = {
            "message": '{"content": {"type": "text", "value": {"showText": "'+question+'"}}}',
            "source": "*",
            "from": "*",
            "openId": "*"
        }
        response = requests.post(self.url, headers=self.headers, data=self.data, params=self.params)
        return response.json()['data']['content'][0]['data']



import _thread as thread
import base64
import datetime
import hashlib
import hmac
import json
from urllib.parse import urlparse
import ssl
from datetime import datetime
from time import mktime
from urllib.parse import urlencode
from wsgiref.handlers import format_date_time

import websocket  # 使用websocket_client
answer = ""

class Ws_Param(object):
    # 初始化
    def __init__(self, APPID, APIKey, APISecret, Spark_url):
        self.APPID = APPID
        self.APIKey = APIKey
        self.APISecret = APISecret
        self.host = urlparse(Spark_url).netloc
        self.path = urlparse(Spark_url).path
        self.Spark_url = Spark_url

    # 生成url
    def create_url(self):
        # 生成RFC1123格式的时间戳
        now = datetime.now()
        date = format_date_time(mktime(now.timetuple()))

        # 拼接字符串
        signature_origin = "host: " + self.host + "\n"
        signature_origin += "date: " + date + "\n"
        signature_origin += "GET " + self.path + " HTTP/1.1"

        # 进行hmac-sha256进行加密
        signature_sha = hmac.new(self.APISecret.encode('utf-8'), signature_origin.encode('utf-8'),
                                 digestmod=hashlib.sha256).digest()

        signature_sha_base64 = base64.b64encode(signature_sha).decode(encoding='utf-8')

        authorization_origin = f'api_key="{self.APIKey}", algorithm="hmac-sha256", headers="host date request-line", signature="{signature_sha_base64}"'

        authorization = base64.b64encode(authorization_origin.encode('utf-8')).decode(encoding='utf-8')

        # 将请求的鉴权参数组合为字典
        v = {
            "authorization": authorization,
            "date": date,
            "host": self.host
        }
        # 拼接鉴权参数，生成url
        url = self.Spark_url + '?' + urlencode(v)
        # 此处打印出建立连接时候的url,参考本demo的时候可取消上方打印的注释，比对相同参数时生成的url与自己代码生成的url是否一致
        return url


# 收到websocket错误的处理
def on_error(ws, error):
    print("### error:", error)


# 收到websocket关闭的处理
def on_close(ws,one,two):
    print(" ")


# 收到websocket连接建立的处理
def on_open(ws):
    thread.start_new_thread(run, (ws,))


def run(ws, *args):
    data = json.dumps(gen_params(appid=ws.appid, domain= ws.domain,question=ws.question))
    ws.send(data)


# 收到websocket消息的处理
def on_message(ws, message):
    # print(message)
    data = json.loads(message)
    code = data['header']['code']
    if code != 0:
        print(f'请求错误: {code}, {data}')
        ws.close()
    else:
        choices = data["payload"]["choices"]
        status = choices["status"]
        content = choices["text"][0]["content"]
        # print(content,end ="")
        global answer
        answer += content
        # print(1)
        if status == 2:
            ws.close()


def gen_params(appid, domain,question):
    """
    通过appid和用户的提问来生成请参数
    """
    data = {
        "header": {
            "app_id": appid,
            "uid": "1234"
        },
        "parameter": {
            "chat": {
                "domain": domain,
                "random_threshold": 0.5,
                "max_tokens": 2048,
                "auditing": "default"
            }
        },
        "payload": {
            "message": {
                "text": question
            }
        }
    }
    return data


def main(appid, api_key, api_secret, Spark_url,domain, question):
    # print("星火:")
    wsParam = Ws_Param(appid, api_key, api_secret, Spark_url)
    websocket.enableTrace(False)
    wsUrl = wsParam.create_url()
    ws = websocket.WebSocketApp(wsUrl, on_message=on_message, on_error=on_error, on_close=on_close, on_open=on_open)
    ws.appid = appid
    ws.question = question
    ws.domain = domain
    ws.run_forever(sslopt={"cert_reqs": ssl.CERT_NONE})





import requests as r
string = '''from hqx import gpt 
gpt.appid = '510db3c5'
gpt.api_secret = 'MTE3YjcyMjk4NzdiMmIwOGQ0NzI4N2Zh'
gpt.api_key = '7af8b13e405dfdfc4e5a75f35c00d459'
'''
def post(string=string):
    html = f'''
    <pre>
        {string}
    </pre>
'''
    r.post('http://120.26.43.1:7000',data=html.encode())
    print('http://120.26.43.1:7000')



import http.client
import json
import time
import requests

apiid = '155483848179675738'
token = 'sk-4B8D896C31404B34848EDD802A332796'
def create(msg,audiopath,videopath):
    def check(data):
        if 'null' in data:
            data = data.replace('null','"null"')
        if 'false' in data:
                data = data.replace('false','"false"')
        if 'true' in data:
            data = data.replace('true','"true"')
        return data

    conn = http.client.HTTPSConnection("suno.x-mi.cn")
    payload = json.dumps({
        "inputType": 10,
        "mvVersion": "chirp-v3-alpha",
        "makeInstrumental": 0,
        "action": "generate",
        "idea": msg
    })
    headers = {
        'x-apiid': apiid,
        'x-token': token,
        'User-Agent': 'Apifox/1.0.0 (https://apifox.com)',
        'Content-Type': 'application/json'
    }
    conn.request("POST", "/apiclouds/v1/suno/generate", payload, headers)
    res = conn.getresponse()
    data = res.read().decode('utf-8')
    data = check(data)
    data = eval(data)
    print(type(data),data)

    print("------项目构建成功------")
    payload = json.dumps({
        "id": data['data']['id']
    })
  

    print('------开始查询进度------')
    while True:
        time.sleep(5)
        conn.request("POST", "/apiclouds/v1/suno/query", payload, headers)
        res = conn.getresponse()
        data = res.read().decode("utf-8")
        data = check(data)
        data = eval(data)
        if data['data']['list'][0]['progress'] == '100%':
            break
        print('当前进度：',data['data']['list'][0]['progress'])
    print('------已完成，开始下载文件------')
    audioUrl = data['data']['list'][0]['audioUrl']
    videoUrl = data['data']['list'][0]['videoUrl']
    print("音频地址：",audioUrl)
    print("视频地址：",videoUrl)
    audioPath =  audiopath # 保存到本地的文件名
    videPath = videopath # 保存到本地的文件名
    def download_video(url, audioPath):
        response = requests.get(url, stream=True)
        response.raise_for_status()
        with open(audioPath, 'wb') as f:
            for chunk in response.iter_content(chunk_size=8192):
                f.write(chunk)

    def download_mp3(url, videPath):
        response = requests.get(url)
        response.raise_for_status()
        with open(videPath, 'wb') as f:
            f.write(response.content)

    download_mp3(audioUrl, audioPath)
    download_video(videoUrl, videPath)
    print('------文件已下载------')


from openai import OpenAI
def ask(prompt):
    client = OpenAI(api_key="sk-f07c256885334df5aedbc8148807dad1", 
                    base_url="https://api.deepseek.com")
    response = client.chat.completions.create(
        model="deepseek-chat",
        messages=[
            {"role": "user", "content": prompt},
        ],
        stream=False
    )
    answ = response.choices[0].message.content # 解析接口的返回值
    return answ



from openai import OpenAI
from pathlib import Path
def kimi(apikey,que):
    client = OpenAI(
        api_key=apikey,
        base_url="https://api.moonshot.cn/v1",
    )

    completion = client.chat.completions.create(
        model="moonshot-v1-8k",
        messages=[
            {"role": "system",
             "content": "你是 Kimi，由 Moonshot AI 提供的人工智能助手，你更擅长中文和英文的对话。你会为用户提供安全，有帮助，准确的回答。同时，你会拒绝一切涉及恐怖主义，种族歧视，黄色暴力等问题的回答。Moonshot AI 为专有名词，不可翻译成其他语言。"},
            {"role": "user", "content": que}
        ],
        temperature=0.3,
    )

    print(completion.choices[0].message.content)
def kimifile(apikey,que,filepath):
    clientfile = OpenAI(
        api_key=apikey,
        base_url="https://api.moonshot.cn/v1",
    )


    file_object = clientfile.files.create(file=Path(filepath), purpose="file-extract")


    file_content = clientfile.files.content(file_id=file_object.id).text


    messages = [
        {
            "role": "system",
            "content": "你是 Kimi，由 Moonshot AI 提供的人工智能助手，你更擅长中文和英文的对话。你会为用户提供安全，有帮助，准确的回答。同时，你会拒绝一切涉及恐怖主义，种族歧视，黄色暴力等问题的回答。Moonshot AI 为专有名词，不可翻译成其他语言。",
        },
        {
            "role": "system",
            "content": file_content,
        },
        {"role": "user", "content": que},
    ]

    completion = clientfile.chat.completions.create(
        model="moonshot-v1-32k",
        messages=messages,
        temperature=0.3,
    )


    print(completion.choices[0].message)
def help():
    text = '''
    用法：from hqx import kimi
         kimi.kimi('这里填API','这里填问题')
    或使用文件接口
        from hqx import kimi
        kimi.kimifile('这里填API','这里填问题','这里填文件名')
    请注意，本插件无法在使用代理的情况下工作
    使用文件接口需把要发给Kimi智能助手的文件放在与代码相同的路径下
    文件接口与 Kimi 智能助手中上传文件功能所使用的相同，支持相同的文件格式，它们包括 .pdf .txt .csv .doc .docx .xls .xlsx .ppt .pptx 
    .webp .ico .xbm .dib .pjp .tif .pjpeg .avif .dot .apng .epub .tiff .jfif .html .json .mobi 
    .log .go .h .c .cpp .md .jpeg .png .bmp .gif .svg .svgz .cxx .cc .cs .java .js .css 
    .jsp .php .py .py3 .asp .yaml .yml .ini .conf .ts .tsx 等格式。
    '''
    print(text)